main.get_tf — DarkHistory documentation

# main.get_tf

`main.` `get_tf`(rs, xHII, xHeII, dlnz, coarsen_factor=1)

  Returns the interpolated transfer functions.

  Parameters: | rs : float The current redshift (1+z) to obtain the functions. xHII : float The ionization fraction nHII/nH. xHeII : float The ionization fraction nHeII/nH. dlnz : float The dlnz of the output transfer functions. coarsen_factor : int The coarsening factor for the output transfer functions.
  Returns: | tuple Contains the high-energy photon, low-energy photon, low-energy electron, upscattered CMB photon energy and high-energy deposition transfer functions.

#### Previous topic

main.get_elec_cooling_data

#### Next topic

config

### This Page

Show Source